@@ -77,14 +77,14 @@ def load_workbook(filename, use_iterators = False):
         _load_workbook(wb, archive, filename, use_iterators)
     except KeyError, e:
         raise InvalidFileException(unicode(e))
-    except Exception, e:
-        raise e
     finally:
         archive.close()
     return wb
 
 def _load_workbook(wb, archive, filename, use_iterators):
 
+    valid_files = archive.namelist()
+
     # get workbook-level information
     wb.properties = read_properties_core(archive.read(ARC_CORE))
     try:
@@ -95,11 +95,15 @@ def _load_workbook(wb, archive, filename, use_iterators):
 
     # get worksheets
     wb.worksheets = []  # remove preset worksheet
-    sheet_names = read_sheets_titles(archive.read(ARC_APP))
+    sheet_names = read_sheets_titles(archive.read(ARC_WORKBOOK))
     for i, sheet_name in enumerate(sheet_names):
+
         sheet_codename = 'sheet%d.xml' % (i + 1)
         worksheet_path = '%s/%s' % (PACKAGE_WORKSHEETS, sheet_codename)
 
+        if not worksheet_path in valid_files:
+            continue
+
         if not use_iterators:
             new_ws = read_worksheet(archive.read(worksheet_path), wb, sheet_name, string_table, style_table)
         else:
