@@ -30,7 +30,7 @@ from openpyxl.shared.xmltools import fromstring, QName
 from openpyxl.shared.ooxml import NAMESPACES
 from openpyxl.workbook import DocumentProperties
 from openpyxl.shared.date_time import W3CDTF_to_datetime
-from openpyxl.namedrange import NamedRange, split_named_range
+from openpyxl.namedrange import NamedRange, NamedRangeContainingValue, split_named_range, refers_to_range
 
 import datetime
 
@@ -76,40 +76,13 @@ def read_properties_core(xml_source):
     return properties
 
 
-def get_number_of_parts(xml_source):
-    """Get a list of contents of the workbook."""
-    parts_size = {}
-    parts_names = []
-    root = fromstring(xml_source)
-    heading_pairs = root.find(QName('http://schemas.openxmlformats.org/officeDocument/2006/extended-properties',
-            'HeadingPairs').text)
-    vector = heading_pairs.find(QName(NAMESPACES['vt'], 'vector').text)
-    children = vector.getchildren()
-    for child_id in range(0, len(children), 2):
-        part_name = children[child_id].find(QName(NAMESPACES['vt'],
-                'lpstr').text).text
-        if not part_name in parts_names:
-            parts_names.append(part_name)
-        part_size = int(children[child_id + 1].find(QName(
-                NAMESPACES['vt'], 'i4').text).text)
-        parts_size[part_name] = part_size
-    return parts_size, parts_names
-
-
 def read_sheets_titles(xml_source):
     """Read titles for all sheets."""
     root = fromstring(xml_source)
-    titles_root = root.find(QName('http://schemas.openxmlformats.org/officeDocument/2006/extended-properties',
-            'TitlesOfParts').text)
-    vector = titles_root.find(QName(NAMESPACES['vt'], 'vector').text)
-    parts, names = get_number_of_parts(xml_source)
-
-    # we can't assume 'Worksheets' to be written in english,
-    # but it's always the first item of the parts list (see bug #22)
-    size = parts[names[0]]
-    children = [c.text for c in vector.getchildren()]
-    return children[:size]
+    titles_root = root.find(QName('http://schemas.openxmlformats.org/spreadsheetml/2006/main',
+            'sheets').text)
 
+    return [sheet.get('name') for sheet in titles_root.getchildren()]
 
 def read_named_ranges(xml_source, workbook):
     """Read named ranges, excluding poorly defined ranges."""
@@ -136,21 +109,28 @@ def read_named_ranges(xml_source, workbook):
                     valid = False
 
             if valid:
-                destinations = split_named_range(name_node.text)
+                if refers_to_range(name_node.text):
+                    destinations = split_named_range(name_node.text)
 
-                new_destinations = []
-                for worksheet, cells_range in destinations:
+                    new_destinations = []
+                    for worksheet, cells_range in destinations:
+                        # it can happen that a valid named range references
+                        # a missing worksheet, when Excel didn't properly maintain
+                        # the named range list
+                        #
+                        # we just ignore them here
+                        worksheet = workbook.get_sheet_by_name(worksheet)
+                        if worksheet:
+                            new_destinations.append((worksheet, cells_range))
 
-                    # it can happen that a valid named range references
-                    # a missing worksheet, when Excel didn't properly maintain
-                    # the named range list
-                    #
-                    # we just ignore them here
-                    worksheet = workbook.get_sheet_by_name(worksheet)
-                    if worksheet:
-                        new_destinations.append((worksheet, cells_range))
+                    named_range = NamedRange(range_name, new_destinations)
+                else:
+                    named_range = NamedRangeContainingValue(range_name, name_node.text)
+
+                location_id = name_node.get("localSheetId")
+                if location_id:
+                    named_range.scope = workbook.worksheets[int(location_id)]
 
-                named_range = NamedRange(range_name, new_destinations)
                 named_ranges.append(named_range)
 
     return named_ranges
